@@ -1,7 +1,7 @@
 /* ****************************************************************************
   This file is part of Lokalize
 
-  Copyright (C) 2007-2009 by Nick Shaforostoff <shafff@ukr.net>
+  Copyright (C) 2007-2011 by Nick Shaforostoff <shafff@ukr.net>
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
@@ -35,6 +35,7 @@
 MergeCatalog::MergeCatalog(QObject* parent, Catalog* baseCatalog, bool saveChanges)
  : Catalog(parent)
  , m_baseCatalog(baseCatalog)
+ , m_modified(false)
 {
     setActivePhase(baseCatalog->activePhase(),baseCatalog->activePhaseRole());
     if (saveChanges)
@@ -58,12 +59,16 @@ void MergeCatalog::copyFromBaseCatalog(const DocPosition& pos, int options)
         if (m_storage->isApproved(ourPos)!=m_baseCatalog->isApproved(pos))
             //kWarning()<<ourPos.entry<<"SHIT";
             m_storage->setApproved(ourPos, m_baseCatalog->isApproved(pos));
+        DocPos p(pos);
+        if (!m_originalHashes.contains(p))
+            m_originalHashes[p]=qHash(m_storage->target(ourPos));
         m_storage->setTarget(ourPos,m_baseCatalog->target(pos));
         setModified(ourPos, true);
 
         if (options&EvenIfNotInDiffIndex && a)
             m_mergeDiffIndex.removeAll(pos.entry);
 
+        m_modified=true;
         emit signalEntryModified(pos);
     }
 }
@@ -124,7 +129,7 @@ MatchItem MergeCatalog::calcMatchItem(const DocPosition& basePos,const DocPositi
     //TODO look also for changed/new <note>s
 
     //translation isn't changed
-    if (baseStorage.targetAllForms(basePos)==mergeStorage.targetAllForms(mergePos))
+    if (baseStorage.targetAllForms(basePos, true)==mergeStorage.targetAllForms(mergePos, true))
     {
         item.translationIsDifferent=baseStorage.isApproved(basePos)!=mergeStorage.isApproved(mergePos);
         item.score+=29+1*item.translationIsDifferent;
@@ -236,10 +241,25 @@ int MergeCatalog::loadFromUrl(const KUrl& url)
         ++it;
     }*/
     m_unmatchedCount=numberOfEntries()-mergePositions.count();
+    m_modified=false;
+    m_originalHashes.clear();
 
     return 0;
 }
 
+bool MergeCatalog::isModified(DocPos pos) const
+{
+    return Catalog::isModified(pos) && m_originalHashes.value(pos)!=qHash(target(pos.toDocPosition()));
+}
+
+bool MergeCatalog::save()
+{
+    bool ok = !m_modified || Catalog::save();
+    if (ok) m_modified=false;
+    m_originalHashes.clear();
+    return ok;
+}
+
 void MergeCatalog::copyToBaseCatalog(DocPosition& pos)
 {
     bool changeContents=m_baseCatalog->msgstr(pos)!=msgstr(pos);
@@ -278,7 +298,7 @@ void MergeCatalog::copyToBaseCatalog(int options)
     DocPosition pos;
     pos.offset=0;
     bool insHappened=false;
-    QLinkedList<int> changed=changedEntries();
+    QLinkedList<int> changed=differentEntries();
     foreach(int entry, changed)
     {
         pos.entry=entry;
