@@ -22,22 +22,19 @@
 #ifndef ALLPRIMITIVETYPES_H_
 #define ALLPRIMITIVETYPES_H_
 
-#include <QtGlobal>
-#include <QByteArray>
-#include <KLocale>
+#include <QSysInfo>
+#include <QtEndian>
 
 #include <size.h>
 #include <address.h>
+#include <abstractbytearraymodel.h>
 
-#include "structviewpreferences.h"
 #include "datatypes/datainformationbase.h"
 
 namespace Okteta
 {
 class AbstractByteArrayModel;
 }
-typedef Kasten2::StructViewPreferences::EnumByteOrder::type ByteOrder;
-typedef Kasten2::StructViewPreferences::EnumByteOrder ByteOrderEnumClass;
 
 /** This union holds the value of one primitive datatype. Maximum size of a datatype is currently 64 bits.
  *  It has methods for reading and writing from @c Okteta::AbstractByteArrayModel */
@@ -143,10 +140,9 @@ union AllPrimitiveTypes
      *  @param bitOffset the bit to start at in the first byte
      *  @return @c true on success, @c false otherwise
      */
-    bool writeBits(const quint8 bitCount, const AllPrimitiveTypes newValue,
-            Okteta::AbstractByteArrayModel* out, const ByteOrder byteOrder,
-            const Okteta::Address address, const BitCount64 bitsRemaining,
-            quint8* const bitOffset);
+    bool writeBits(quint8 bitCount, AllPrimitiveTypes newValue,
+            Okteta::AbstractByteArrayModel* out, QSysInfo::Endian byteOrder,
+            Okteta::Address address, BitCount64 bitsRemaining, quint8* const bitOffset);
     /** Reads given number of bits from @p input and sets value of this union to
      *  the new value.
      *  @p bitOffset is changed in this method so it does not have to be handled later.
@@ -163,35 +159,47 @@ union AllPrimitiveTypes
      *  @param bitOffset the bit to start at in the first byte
      *  @return @c true on success, @c false otherwise
      */
-    bool readBits(const quint8 bitCount,
-            const Okteta::AbstractByteArrayModel* input, const ByteOrder byteOrder,
-            const Okteta::Address address, const BitCount64 bitsRemaining,
+    bool readBits(quint8 bitCount, const Okteta::AbstractByteArrayModel* input,
+            QSysInfo::Endian byteOrder, Okteta::Address address, BitCount64 bitsRemaining,
             quint8* const bitOffset);
 
     template<typename T> T value() const;
+    /**
+     * Read data of type @p T from the model. Range checking must have been performed before
+     * @param input the input to read from
+     * @param address the starting address
+     * @param endianess the endianess to use when reading
+     * @param bitOffset the number of bits into the first byte (different depending on endianess)
+     * @return the read value
+     */
+    //TODO bool* ok parameter for when reading from model can cause errors (or exceptions sometime?)
+    template<typename T> static T readValue(const Okteta::AbstractByteArrayModel* input, Okteta::Address address,
+            QSysInfo::Endian endianess, quint8 bitOffset);
+    //TODO add writeValue
 
 private:
-    void readDataLittleEndian(const quint8 bitCount,
-            const Okteta::AbstractByteArrayModel* input,
-            const Okteta::Address address, const quint8 bo);
-    void writeDataLittleEndian(const quint8 bitCount,
-            const AllPrimitiveTypes newValue, Okteta::AbstractByteArrayModel *out,
-            const Okteta::Address address, const quint8 bo) const;
+    template<int size> static typename QIntegerForSize<size>::Unsigned readValuePrivate(
+            const Okteta::AbstractByteArrayModel* input, Okteta::Address address,
+            QSysInfo::Endian endianess, quint8 bitOffset);
+    template<int size> static typename QIntegerForSize<size>::Unsigned readRawBytes(
+            const Okteta::AbstractByteArrayModel* input, Okteta::Address address);
 
-    void readDataBigEndian(const quint8 bitCount,
-            const Okteta::AbstractByteArrayModel* input,
-            const Okteta::Address address, const quint8 bo);
-    void writeDataBigEndian(const quint8 bitCount, const AllPrimitiveTypes newValue,
-            Okteta::AbstractByteArrayModel *out, const Okteta::Address address,
-            const quint8 bo) const;
+    void readDataLittleEndian(quint8 bitCount, const Okteta::AbstractByteArrayModel* input,
+            Okteta::Address address, quint8 bo);
+    void writeDataLittleEndian(quint8 bitCount, AllPrimitiveTypes newValue,
+            Okteta::AbstractByteArrayModel *out, Okteta::Address address, quint8 bo) const;
+
+    void readDataBigEndian(quint8 bitCount, const Okteta::AbstractByteArrayModel* input,
+            Okteta::Address address, quint8 bo);
+    void writeDataBigEndian(quint8 bitCount, AllPrimitiveTypes newValue,
+            Okteta::AbstractByteArrayModel *out, Okteta::Address address, quint8 bo) const;
 
     //optimised methods for reading/writing full bytes
-    void readFullBytes(const quint8 byteCount,
-            const Okteta::AbstractByteArrayModel* input, const ByteOrder byteOrder,
-            const Okteta::Address address);
-    void writeFullBytes(const quint8 byteCount, const AllPrimitiveTypes newValue,
-            Okteta::AbstractByteArrayModel* out, const ByteOrder byteOrder,
-            const Okteta::Address address);
+    void readFullBytes(quint8 byteCount, const Okteta::AbstractByteArrayModel* input,
+            QSysInfo::Endian byteOrder, Okteta::Address address);
+    void writeFullBytes(quint8 byteCount, AllPrimitiveTypes newValue,
+            Okteta::AbstractByteArrayModel* out, QSysInfo::Endian byteOrder,
+            Okteta::Address address);
 };
 
 template<> inline quint8 AllPrimitiveTypes::value<quint8>() const { return ubyteValue; }
@@ -205,4 +213,78 @@ template<> inline qint64 AllPrimitiveTypes::value<qint64>() const { return longV
 template<> inline float AllPrimitiveTypes::value<float>() const { return floatValue; }
 template<> inline double AllPrimitiveTypes::value<double>() const { return doubleValue; }
 
+
+template<typename T>
+inline T AllPrimitiveTypes::readValue(const Okteta::AbstractByteArrayModel* input,
+        Okteta::Address address, QSysInfo::Endian endianess, quint8 bitOffset)
+{
+    //check for out of bounds
+    Q_ASSERT(BitCount64(input->size() - address) * 8 - bitOffset >= sizeof(T) * 8);
+    Q_ASSERT(bitOffset < 8);
+    //this union exists to force unsigned shifts
+    union {
+        T value;
+        typename QIntegerForSizeof<T>::Unsigned unsignedValue;
+    } u;
+    u.unsignedValue = readValuePrivate<sizeof(T)>(input, address, endianess, bitOffset);
+    return u.value;
+}
+
+template<int size>
+inline typename QIntegerForSize<size>::Unsigned AllPrimitiveTypes::readValuePrivate(
+        const Okteta::AbstractByteArrayModel* input, Okteta::Address address,
+        QSysInfo::Endian endianess, quint8 bitOffset)
+{
+    typename QIntegerForSize<size>::Unsigned unsignedValue = readRawBytes<size>(input, address);
+    if (endianess != QSysInfo::ByteOrder)
+    {
+        //swap the byte order if machine endianess does not match requested endianess
+        unsignedValue = qbswap(unsignedValue);
+    }
+    if (Q_UNLIKELY(bitOffset != 0))
+    {
+        quint8 lastByte = input->byte(address + size);
+        //handle the remaining bits
+        if (endianess == QSysInfo::BigEndian)
+        {
+            //the coming bits are the least significant, and range from bit (8-bitOffset)..7
+            unsignedValue <<= bitOffset;
+            lastByte >>= 8 - bitOffset; //unsigned shift
+            Q_ASSERT((unsignedValue & lastByte) == 0); //must not overlap
+            unsignedValue |= lastByte;
+        }
+        else
+        {
+            //the coming bits are the most significant bits and range from 0..bitOffset
+            unsignedValue >>= bitOffset;
+            //promote lastByte to unsigned T and mask off the interesting bits
+            typename QIntegerForSize<size>::Unsigned tmp = lastByte & ((1u << bitOffset) - 1);
+            tmp <<= (size * 8) - bitOffset;
+            unsignedValue |= tmp;
+        }
+    }
+    return unsignedValue;
+}
+
+template<int size>
+inline typename QIntegerForSize<size>::Unsigned AllPrimitiveTypes::readRawBytes(
+        const Okteta::AbstractByteArrayModel* input, Okteta::Address address)
+{
+    union {
+        typename QIntegerForSize<size>::Unsigned value;
+        Okteta::Byte bytes[size];
+    } buf;
+    Okteta::Size read = input->copyTo(buf.bytes, address, size);
+    Q_ASSERT(read == size);
+    return buf.value;
+}
+
+//specialize it for the case where we only need to read one byte
+template<>
+inline quint8 AllPrimitiveTypes::readRawBytes<1>(
+        const Okteta::AbstractByteArrayModel* input, Okteta::Address address)
+{
+    return input->byte(address);
+}
+
 #endif /* ALLPRIMITIVETYPES_H_ */
