@@ -22,23 +22,27 @@
 #include "datainformation.h"
 #include "topleveldatainformation.h"
 #include "additionaldata.h"
+#include "structviewpreferences.h"
+#include "../script/scriptlogger.h"
 
 #include <QScriptValue>
+#include <QScriptEngine>
 
 #include <KLocale>
 #include <KLineEdit>
 #include <KIcon>
+#include <KColorScheme>
 
 DataInformation::DataInformation(const QString& name, DataInformationBase* parent)
-        : mValidationSuccessful(false), mHasBeenValidated(false), mWasAbleToRead(false),
-                mByteOrder(EndianessInherit), mAdditionalData(0), mParent(parent), mName(name)
+        : mValidationSuccessful(false), mHasBeenValidated(false), mHasBeenUpdated(false),
+          mWasAbleToRead(false), mByteOrder(EndianessInherit), mLoggedData(ScriptLogger::LogInvalid),
+                mParent(parent), mName(name)
 {
 }
 
 DataInformation::DataInformation(const DataInformation& d)
-        : mValidationSuccessful(d.mValidationSuccessful),
-                mHasBeenValidated(d.mHasBeenValidated), mWasAbleToRead(d.mWasAbleToRead),
-                mByteOrder(d.mByteOrder), mParent(0), mName(d.mName)
+        : mValidationSuccessful(false), mHasBeenValidated(false), mHasBeenUpdated(false), mWasAbleToRead(false),
+                mByteOrder(d.mByteOrder), mLoggedData(ScriptLogger::LogInvalid), mParent(0), mName(d.mName)
 {
     if (d.mAdditionalData)
         mAdditionalData.reset(new AdditionalData(*(d.mAdditionalData)));
@@ -67,17 +71,14 @@ QString DataInformation::sizeString() const
     }
 }
 
-BitCount32 DataInformation::positionRelativeToRoot(int index) const
-        {
+BitCount64 DataInformation::positionInFile(Okteta::Address start) const
+{
     Q_CHECK_PTR(mParent);
-    //FIXME this needs updating to support bitfield marking
     if (mParent->isTopLevel())
-        return 0;
+        return start * 8; //this is the root of the structure
 
-    //TODO add a method offset(const DataInformation* const) for efficiency
-    DataInformation* par = mParent->asDataInformation();
-    //row defaults to -1
-    return par->offset(index < 0 ? row() : index) + par->positionRelativeToRoot();
+    const DataInformation* par = mParent->asDataInformation();
+    return par->childPosition(this, start);
 }
 
 DataInformation* DataInformation::mainStructure()
@@ -112,7 +113,6 @@ void DataInformation::unsetValidationError()
 
 void DataInformation::setValidationError(QString errorMessage)
 {
-    AdditionalData* data = additionalData();
     if (errorMessage.isEmpty())
     {
         unsetValidationError();
@@ -120,51 +120,40 @@ void DataInformation::setValidationError(QString errorMessage)
     }
     else
     {
-        setValidationSuccessful(false);
+        mValidationSuccessful = false;
+        AdditionalData* data = additionalData();
         if (data)
             data->setValidationError(errorMessage);
         else
         {
             AdditionalData* newData = new AdditionalData();
             newData->setValidationError(errorMessage);
+            setAdditionalData(newData);
         }
     }
 }
 
-bool DataInformation::validationSuccessful() const
-{
-    return mValidationSuccessful;
-}
-
-void DataInformation::setValidationSuccessful(bool successful)
-{
-    mValidationSuccessful = successful;
-    setHasBeenValidated(true);
-}
-
-bool DataInformation::hasBeenValidated() const
-{
-    return mHasBeenValidated;
-}
-
-void DataInformation::setHasBeenValidated(bool hasBeen)
-{
-    mHasBeenValidated = hasBeen;
-}
-
 void DataInformation::resetValidationState()
 {
     unsetValidationError();
     mHasBeenValidated = false;
     mValidationSuccessful = false;
 }
+
 void DataInformation::beginRead()
 {
+    mHasBeenUpdated = false;
+    mWasAbleToRead = false;
+    mHasBeenValidated = false;
+    mLoggedData = ScriptLogger::LogInvalid;
+    const uint numChildren = childCount();
+    if (numChildren > 0 && childAt(0)->isDummy())
+        return; //first child is dummy -> all are
+    //otherwise start read for all children
     for (uint i = 0; i < childCount(); ++i)
     {
         childAt(i)->beginRead();
     }
-    mWasAbleToRead = false;
 }
 
 ScriptLogger* DataInformation::logger() const
@@ -207,7 +196,8 @@ void DataInformation::setUpdateFunc(const QScriptValue& func)
     {
         if (!func.isFunction())
         {
-            kWarning() << func.toString() << "is not a function!";
+            logWarn() << "cannot set update function since "
+                    << func.toString() << "is not a function!";
             return;
         }
         if (data)
@@ -250,7 +240,8 @@ void DataInformation::setValidationFunc(const QScriptValue& func)
     {
         if (!func.isFunction())
         {
-            kWarning() << func.toString() << "is not a function!";
+            logWarn() << "cannot set validation function since "
+                    << func.toString() << "is not a function!";
             return;
         }
         if (data)
@@ -266,32 +257,21 @@ void DataInformation::setValidationFunc(const QScriptValue& func)
     }
 }
 
-int DataInformation::indexOf(const DataInformation* const data) const
-        {
-    Q_UNUSED(data)
-    Q_ASSERT_X(false, "DataInformation::indexOf", "this should never happen!");
-    return 0;
-}
-
-QVariant DataInformation::childData(int row, int column, int role) const
-        {
-    Q_ASSERT_X(false, "DataInformation::childData", "this should never happen!");
-    Q_UNUSED(row)
-    Q_UNUSED(column)
-    Q_UNUSED(role)
-    return QVariant(); //no children -> no child data
-}
-
 QVariant DataInformation::data(int column, int role) const
-        {
+{
     if (role == Qt::DisplayRole)
     {
         if (column == ColumnName)
-            return name();
+        {
+            if (mParent && mParent->isArray())
+                return QString(QLatin1Char('[') + QString::number(row()) + QLatin1Char(']'));
+            else
+                return name();
+        }
         if (column == ColumnType)
             return typeName();
         if (column == ColumnValue)
-            return valueString();
+            return mWasAbleToRead ? valueString() : eofReachedData(Qt::DisplayRole);
     }
     else if (role == Qt::ToolTipRole)
     {
@@ -302,12 +282,30 @@ QVariant DataInformation::data(int column, int role) const
         //XXX better icons?
         if (mHasBeenValidated)
             return KIcon(QLatin1String(mValidationSuccessful ? "task-complete" : "dialog-warning"));
+        if (mLoggedData != ScriptLogger::LogInvalid)
+            return ScriptLogger::iconForLevel(mLoggedData);
     }
+    else if (!mWasAbleToRead && column == ColumnValue)
+        return eofReachedData(role);
     return QVariant();
 }
 
+QVariant DataInformation::eofReachedData(int role)
+{
+    //whenever color scheme changes application must be restarted to have the correct color
+    static KColorScheme scheme(QPalette::Active);
+
+    if (role == Qt::DisplayRole)
+        return i18nc("invalid value (End of file reached)", "<EOF reached>");
+    else if (role == Qt::ForegroundRole)
+        return scheme.foreground(KColorScheme::NegativeText);
+    return QVariant();
+}
+
+
 QString DataInformation::tooltipString() const
 {
+    QString valueStr = mWasAbleToRead ? valueString() : eofReachedData(Qt::DisplayRole).toString();
     if (mHasBeenValidated && !mValidationSuccessful)
     {
         QString validationMsg = validationError();
@@ -322,24 +320,17 @@ QString DataInformation::tooltipString() const
                     "Validation failed: \"%1\"", additionalData()->validationError());
         }
         return i18n("Name: %1\nValue: %2\n\nType: %3\nSize: %4\n\n%5", name(),
-                valueString(), typeName(), sizeString(), validationMsg);
+                valueStr, typeName(), sizeString(), validationMsg);
     }
     else
     {
         return i18n("Name: %1\nValue: %2\n\nType: %3\nSize: %4", name(),
-                valueString(), typeName(), sizeString());
+                valueStr, typeName(), sizeString());
     }
 }
 
-Qt::ItemFlags DataInformation::childFlags(int row, int column, bool fileLoaded) const
-        {
-    Q_ASSERT_X(false, "DataInformation::childFlags()",
-            "Only subclass versions of this should be called");
-    return childAt(row)->flags(column, fileLoaded);
-}
-
-DataInformation* DataInformation::child(QString name) const
-        {
+DataInformation* DataInformation::child(const QString& name) const
+{
     int size = childCount();
     for (int i = 0; i < size; ++i)
     {
@@ -350,41 +341,6 @@ DataInformation* DataInformation::child(QString name) const
     return 0;
 }
 
-QPair<DataInformation*, QString> DataInformation::findChildForDynamicArrayLength(
-        const QString& name, uint upTo) const
-        {
-    Q_ASSERT(upTo <= childCount());
-    for (int i = upTo - 1; i >= 0; --i)
-    {
-        DataInformation* current = childAt(i);
-        QString start = name;
-        if (current->canHaveChildren())
-        {
-            QPair<DataInformation*, QString> tmp = findChildForDynamicArrayLength(name,
-                    current->childCount());
-            current = tmp.first;
-            if (current)
-                start = start + tmp.second;
-        }
-        if (current && current->name() == name)
-        {
-            return qMakePair(current, QString(start + QLatin1String(".value")));
-        }
-    }
-    if (!parent() || parent()->isTopLevel())
-        return QPair<DataInformation*, QString>(0, QString());
-
-    QPair<DataInformation*, QString> ret =
-            parent()->asDataInformation()->findChildForDynamicArrayLength(name, row());
-    if (ret.first)
-    {
-        //found one
-        return qMakePair(ret.first, QString(QLatin1String("parent.") + ret.second));
-    }
-    else
-        return QPair<DataInformation*, QString>(0, QString());
-}
-
 TopLevelDataInformation* DataInformation::topLevelDataInformation() const
 {
     Q_CHECK_PTR(mParent);
@@ -403,27 +359,6 @@ int DataInformation::row() const
         return mParent->asDataInformation()->indexOf(this);
 }
 
-QWidget* DataInformation::createChildEditWidget(uint, QWidget*) const
-        {
-    Q_ASSERT_X(false, "DataInformation::createChildEditWidget",
-            "only implemented so not all subclasses have to, since it will never be called there. Error!");
-    return 0;
-
-}
-
-void DataInformation::setChildWidgetData(uint, QWidget*) const
-        {
-    Q_ASSERT_X(false, "DataInformation::setChildWidgetData",
-            "only implemented so not all subclasses have to, since it will never be called there. Error!");
-}
-
-QVariant DataInformation::dataFromChildWidget(uint, const QWidget*) const
-        {
-    Q_ASSERT_X(false, "DataInformation::dataFromChildWidget",
-            "only implemented so not all subclasses have to, since it will never be called there. Error!");
-    return QVariant();
-}
-
 QString DataInformation::fullObjectPath() const
 {
     DataInformationBase* par = parent();
@@ -445,3 +380,27 @@ void DataInformation::setAdditionalData(AdditionalData* data)
 {
     mAdditionalData.reset(data);
 }
+
+QSysInfo::Endian DataInformation::effectiveByteOrder() const
+{
+    switch (mByteOrder)
+    {
+    case EndiannessBig:
+        return QSysInfo::BigEndian;
+    case EndianessLittle:
+        return QSysInfo::LittleEndian;
+    case EndianessFromSettings:
+        return static_cast<QSysInfo::Endian>(Kasten2::StructViewPreferences::byteOrder());
+    default: //inherit
+        return (mParent && !mParent->isTopLevel()) ?
+                mParent->asDataInformation()->effectiveByteOrder() :
+                static_cast<QSysInfo::Endian>(Kasten2::StructViewPreferences::byteOrder());
+    }
+}
+
+QScriptValue DataInformation::toScriptValue(QScriptEngine* engine, ScriptHandlerInfo* handlerInfo)
+{
+    QScriptValue ret = engine->newObject(scriptClass(handlerInfo));
+    ret.setData(engine->toScriptValue(static_cast<DataInformation*>(this)));
+    return ret;
+}
