@@ -42,6 +42,8 @@
 
 #include "script/scripthandler.h"
 #include "datatypes/datainformation.h"
+#include "structviewpreferences.h"
+
 
 namespace Kasten2
 {
@@ -51,7 +53,7 @@ class StructToolPrivate
 public:
     StructToolPrivate()
             : mByteArrayView(0), mByteArrayModel(0), mCursorIndex(0), mByteOrder(
-                    StructViewPreferences::byteOrder()), mManager(new StructuresManager()),
+                    (QSysInfo::Endian)StructViewPreferences::byteOrder()), mManager(new StructuresManager()),
                     mWritingData(false), mCurrentItemDataChanged(false)
     {
     }
@@ -62,7 +64,7 @@ public:
     Okteta::Address mCursorIndex;
 
     // settings
-    StructViewPreferences::EnumByteOrder::type mByteOrder;
+    QSysInfo::Endian mByteOrder;
     QScopedPointer<StructuresManager> mManager;
     TopLevelDataInformation::List mData;
     TopLevelDataInformation::List mInvalidData;
@@ -91,12 +93,12 @@ StructTool::~StructTool()
 {
 }
 
-void StructTool::setByteOrder(StructViewPreferences::EnumByteOrder::type order)
+void StructTool::setByteOrder(QSysInfo::Endian order)
 {
-    if (order != StructViewPreferences::byteOrder() || order != d->mByteOrder)
+    if (order != (QSysInfo::Endian)StructViewPreferences::byteOrder() || order != d->mByteOrder)
     {
         emit byteOrderChanged();
-        StructViewPreferences::setByteOrder(order);
+        StructViewPreferences::setByteOrder((StructViewPreferences::EnumByteOrder::type)order);
         d->mByteOrder = order;
         updateData(Okteta::ArrayChangeMetricsList());
     }
@@ -147,10 +149,10 @@ void StructTool::onCursorPositionChange(Okteta::Address pos)
 
 void StructTool::setByteOrder(int order)
 {
-    if (order == StructViewPreferences::EnumByteOrder::LittleEndian)
-        setByteOrder(StructViewPreferences::EnumByteOrder::LittleEndian);
-    else if (order == StructViewPreferences::EnumByteOrder::BigEndian)
-        setByteOrder(StructViewPreferences::EnumByteOrder::BigEndian);
+    if (order == QSysInfo::LittleEndian)
+        setByteOrder(QSysInfo::LittleEndian);
+    else if (order == QSysInfo::BigEndian)
+        setByteOrder(QSysInfo::BigEndian);
     else
     {
         kWarning() << "invalid byte order set:" << order;
@@ -169,6 +171,7 @@ void StructTool::onContentsChange(const Okteta::ArrayChangeMetricsList& list)
 
 bool StructTool::setData(const QVariant& value, int role, DataInformation* item, uint row)
 {
+    Q_UNUSED(row)
     if (!d->mByteArrayModel)
         return false;
     if (role != Qt::EditRole)
@@ -180,25 +183,11 @@ bool StructTool::setData(const QVariant& value, int role, DataInformation* item,
     if (topLevel->isLockedFor(d->mByteArrayModel))
         structureStart = topLevel->lockPositionFor(d->mByteArrayModel);
     d->mWritingData = true;
-    quint64 remainingBits = qMax(d->mByteArrayModel->size() - structureStart, 0) * 8;
     bool ret = false;
-    DataInformationBase* par = item->parent();
-    if (item->isDummy())
-    {
-        //we have to use setChildData() since this item is not valid
-        DataInformation* parent = static_cast<DataInformation*>(par);
-        quint64 offs = parent->positionRelativeToRoot();
-        quint8 bitOffs = offs % 8;
-        ret = parent->setChildData(row, value, d->mByteArrayModel, structureStart + (offs / 8),
-                remainingBits - offs, bitOffs);
-    }
-    else
-    {
-        quint64 offs = item->positionRelativeToRoot(row);
-        quint8 bitOffs = offs % 8;
-        ret = item->setData(value, d->mByteArrayModel, structureStart + (offs / 8),
-                remainingBits - offs, bitOffs);
-    }
+    BitCount64 position = item->positionInFile(structureStart);
+    const quint64 remainingBits = qMax(d->mByteArrayModel->size() * 8 - qint64(position), qint64(0));
+    quint8 bitOffs = position % 8;
+    ret = item->setData(value, d->mByteArrayModel, position / 8, remainingBits, bitOffs);
     d->mWritingData = false; //finished
     //XXX: this is inefficient, best would be to only update the changed value
     updateData(Okteta::ArrayChangeMetricsList()); //update once after writing
@@ -358,14 +347,10 @@ void StructTool::mark(const QModelIndex& idx)
     Q_CHECK_PTR(data->topLevelDataInformation());
     const Okteta::Address baseAddress = startAddress(data);
     //FIXME support marking of partial bytes
-    int length;
-    if (data->isDummy())
-        length = static_cast<const DataInformation*>(data->parent())->childSize(idx.row()) / 8;
-    else
-        length = data->size() / 8;
-    int maxLen = d->mByteArrayModel->size() - baseAddress;
+    int length = data->size() / 8;
+    const int maxLen = d->mByteArrayModel->size() - baseAddress;
     length = qMin(length, maxLen);
-    const Okteta::Address startOffset = baseAddress + data->positionRelativeToRoot(idx.row()) / 8;
+    const Okteta::Address startOffset = data->positionInFile(baseAddress) / 8;
     const Okteta::AddressRange markingRange =
             Okteta::AddressRange::fromWidth(startOffset, length);
     d->mByteArrayView->setMarking(markingRange, true);
@@ -472,7 +457,7 @@ StructuresManager* StructTool::manager() const
     return d->mManager.data();
 }
 
-StructViewPreferences::EnumByteOrder::type StructTool::byteOrder() const
+QSysInfo::Endian StructTool::byteOrder() const
 {
     return d->mByteOrder;
 }
