@@ -25,7 +25,7 @@
 #include "umldoc.h"
 
 // qt includes
-#include <QtCore/QRegExp>
+#include <QRegExp>
 
 #include <stdio.h>
 
