@@ -20,7 +20,7 @@
 #ifndef PREPROCESSLEXER_H
 #define PREPROCESSLEXER_H
 
-#include <QtCore/QChar>
+#include <QChar>
 
 namespace boost { namespace spirit { namespace classic { namespace impl {
   bool isalnum_( QChar const& c);
@@ -34,16 +34,15 @@ namespace boost { namespace spirit { namespace classic { namespace impl {
 #include "driver.h"
 #include "skip_rule.hpp"
 
-#include <QtCore/QString>
-#include <QtCore/QMap>
-#include <QtCore/QPair>
+#include <QMap>
+#include <QPair>
+#include <QString>
 
 using boost::spirit::classic::parse_info;
 using boost::spirit::classic::rule;
 using boost::spirit::classic::scanner;
 using boost::spirit::classic::ext::skip_rule_parser;
 
-typedef boost::spirit::classic::position_iterator<QChar const*> CharIterator;
 typedef rule<scanner<CharIterator> > SkipRule;
 typedef skip_rule_parser<SkipRule, CharIterator> CharParser;
 typedef scanner<CharIterator> CharScanner;
@@ -207,6 +206,7 @@ public:
     QString const& preprocessedString() const {return m_preprocessedString;}
 private:
     static int toInt( const Token& token );
+    void dumpToFile();
 
     void addDependence( std::pair<QString, int> const& p_wordAndScope) const {
         m_driver->addDependence(m_driver->currentFileName(),
