@@ -44,9 +44,9 @@ MessageWidgetController::~MessageWidgetController()
  * Saves the values of the widget needed for move/resize.
  * Calls parent method and then saves the value of m_unconstrainedPositionY
  *
- * @param me The QMouseEvent to get the offset from.
+ * @param me The QGraphicsSceneMouseEvent to get the offset from.
  */
-void MessageWidgetController::saveWidgetValues(QMouseEvent *me)
+void MessageWidgetController::saveWidgetValues(QGraphicsSceneMouseEvent *me)
 {
     UMLWidgetController::saveWidgetValues(me);
 
@@ -73,7 +73,7 @@ QCursor MessageWidgetController::getResizeCursor()
  * @param newW The new width for the widget (isn't used).
  * @param newH The new height for the widget.
  */
-void MessageWidgetController::resizeWidget(int newW, int newH)
+void MessageWidgetController::resizeWidget(UMLSceneValue newW, UMLSceneValue newH)
 {
     if (m_messageWidget->sequenceMessageType() == Uml::sequence_message_creation)
         m_messageWidget->setSize(m_messageWidget->width(), newH);
@@ -112,11 +112,11 @@ void MessageWidgetController::resizeWidget(int newW, int newH)
  *                          (isn't used).
  * @param diffY The difference between current Y position and new Y position.
  */
-void MessageWidgetController::moveWidgetBy(int diffX, int diffY)
+void MessageWidgetController::moveWidgetBy(UMLSceneValue diffX, UMLSceneValue diffY)
 {
     Q_UNUSED(diffX);
     m_unconstrainedPositionY += diffY;
-    int newY = constrainPositionY(diffY);
+    UMLSceneValue newY = constrainPositionY(diffY);
 
     if (m_unconstrainedPositionY != newY) {
         if (m_unconstrainedPositionY > m_messageWidget->y()) {
@@ -129,7 +129,7 @@ void MessageWidgetController::moveWidgetBy(int diffX, int diffY)
     m_messageWidget->setY(newY);
 
     if (m_messageWidget->m_sequenceMessageType == Uml::sequence_message_creation) {
-        const int objWidgetHalfHeight = m_messageWidget->m_pOw[Uml::B]->height() / 2;
+        const UMLSceneValue objWidgetHalfHeight = m_messageWidget->m_pOw[Uml::B]->height() / 2;
         m_messageWidget->m_pOw[Uml::B]->UMLWidget::setY(newY - objWidgetHalfHeight);
     }
 
@@ -145,7 +145,7 @@ void MessageWidgetController::moveWidgetBy(int diffX, int diffY)
  * @param diffX The difference between current X position and new X position.
  * @param diffY The difference between current Y position and new Y position.
  */
-void MessageWidgetController::constrainMovementForAllWidgets(int &diffX, int &diffY)
+void MessageWidgetController::constrainMovementForAllWidgets(UMLSceneValue &diffX, UMLSceneValue &diffY)
 {
     diffX = 0;
     diffY = constrainPositionY(diffY) - m_widget->y();
@@ -156,9 +156,9 @@ void MessageWidgetController::constrainMovementForAllWidgets(int &diffX, int &di
  * Executes the action for double click in the widget.
  * Shows the dialog to select the operation of the message.
  *
- * @param me The QMouseEvent which triggered the double click event.
+ * @param me The QGraphicsSceneMouseEvent which triggered the double click event.
  */
-void MessageWidgetController::doMouseDoubleClick(QMouseEvent* me)
+void MessageWidgetController::doMouseDoubleClick(QGraphicsSceneMouseEvent* me)
 {
     Q_UNUSED(me);
     if (m_messageWidget->m_pFText != NULL) {
@@ -176,11 +176,11 @@ void MessageWidgetController::doMouseDoubleClick(QMouseEvent* me)
  * @param diffY The difference between current Y position and new Y position.
  * @return The new Y position, constrained.
  */
-int MessageWidgetController::constrainPositionY(int diffY)
+int MessageWidgetController::constrainPositionY(UMLSceneValue diffY)
 {
-    int newY = m_widget->y() + diffY;
+    UMLSceneValue newY = m_widget->y() + diffY;
 
-    int minY = m_messageWidget->getMinY();
+    UMLSceneValue minY = m_messageWidget->getMinY();
     if (m_messageWidget->m_pFText && !m_messageWidget->m_pFText->displayText().isEmpty()) {
         minY += m_messageWidget->m_pFText->height();
     }
