@@ -13,8 +13,7 @@
 
 // app includes
 #include "associationwidget.h"
-#include "uml.h"
-#include "umlview.h"
+#include "umlscene.h"
 #include "umlwidget.h"
 
 /**
@@ -81,16 +80,16 @@ void ToolBarStateArrow::mousePressEmpty()
 
     // Starts the selection rectangle
     if (m_selectionRect.count() == 0) {
-        m_startPosition = m_pMouseEvent->pos();
+        m_startPosition = m_pMouseEvent->scenePos();
 
         for (int i = 0; i < 4; i++) {
-            UMLSceneLineItem* line = new UMLSceneLineItem;
-            line->setCanvas((m_pUMLScene->canvas()));
-            line->setPoints(m_pMouseEvent->x(), m_pMouseEvent->y(),
-                            m_pMouseEvent->x(), m_pMouseEvent->y());
+            QGraphicsLineItem* line = new QGraphicsLineItem();
+            m_pUMLScene->addItem(line);
+            line->setLine(m_pMouseEvent->scenePos().x(), m_pMouseEvent->scenePos().y(),
+                          m_pMouseEvent->scenePos().x(), m_pMouseEvent->scenePos().y());
             line->setPen(QPen(QColor("grey"), 0, Qt::DotLine));
             line->setVisible(true);
-            line->setZ(100);
+            line->setZValue(100);
             m_selectionRect.append(line);
         }
     }
@@ -126,7 +125,7 @@ void ToolBarStateArrow::mouseReleaseEmpty()
             delete m_selectionRect.takeFirst();
         m_selectionRect.clear();
     } else if (m_pMouseEvent->button() == Qt::RightButton) {
-        m_pUMLScene->setMenu();
+        m_pUMLScene->setMenu(m_pMouseEvent->scenePos().toPoint());
     }
 }
 
@@ -179,24 +178,24 @@ void ToolBarStateArrow::mouseMoveWidget()
 void ToolBarStateArrow::mouseMoveEmpty()
 {
     if (m_selectionRect.count() == 4) {
-        UMLSceneLineItem* line = m_selectionRect.at(0);
-        line->setPoints(m_startPosition.x(), m_startPosition.y(),
-                        m_pMouseEvent->x(), m_startPosition.y());
+        QGraphicsLineItem* line = m_selectionRect.at(0);
+        line->setLine(m_startPosition.x(), m_startPosition.y(),
+                      m_pMouseEvent->scenePos().x(), m_startPosition.y());
 
         line = m_selectionRect.at(1);
-        line->setPoints(m_pMouseEvent->x(), m_startPosition.y(),
-                        m_pMouseEvent->x(), m_pMouseEvent->y());
+        line->setLine(m_pMouseEvent->scenePos().x(), m_startPosition.y(),
+                      m_pMouseEvent->scenePos().x(), m_pMouseEvent->scenePos().y());
 
         line = m_selectionRect.at(2);
-        line->setPoints(m_pMouseEvent->x(), m_pMouseEvent->y(),
-                        m_startPosition.x(), m_pMouseEvent->y());
+        line->setLine(m_pMouseEvent->scenePos().x(), m_pMouseEvent->scenePos().y(),
+                      m_startPosition.x(), m_pMouseEvent->scenePos().y());
 
         line = m_selectionRect.at(3);
-        line->setPoints(m_startPosition.x(), m_pMouseEvent->y(),
-                        m_startPosition.x(), m_startPosition.y());
+        line->setLine(m_startPosition.x(), m_pMouseEvent->scenePos().y(),
+                      m_startPosition.x(), m_startPosition.y());
 
         m_pUMLScene->selectWidgets(m_startPosition.x(), m_startPosition.y(),
-                                  m_pMouseEvent->x(), m_pMouseEvent->y());
+                                   m_pMouseEvent->scenePos().x(), m_pMouseEvent->scenePos().y());
     }
 }
 
