@@ -24,16 +24,22 @@
 // Qt includes
 #include <QMouseEvent>
 #include <QKeyEvent>
-#include <QtGui/QPixmap>
-#include <Q3Canvas>
-#include <QtXml/QDomDocument>
+#include <QPixmap>
+#include <QGraphicsScene>
+#include <QGraphicsItem>
+#include <QDomDocument>
+#include <QGraphicsSceneMouseEvent>
+#include <QGraphicsPolygonItem>
 
 // forward declarations
 class ClassOptionsPage;
 class IDChangeLog;
+class LayoutGrid;
 class ListPopupMenu;
 class FloatingTextWidget;
 class ObjectWidget;
+class ToolBarState;
+class ToolBarStateFactory;
 class UMLFolder;
 class UMLApp;
 class UMLDoc;
@@ -53,47 +59,41 @@ class QMouseEvent;
 class QPrinter;
 class QShowEvent;
 class UMLScene;
-class UMLSceneMouseEvent;
 
 /// uml related types - makes it easier to switch to QGraphicsScene types
 // base types
-typedef QPoint UMLScenePoint;
-typedef QRect UMLSceneRect;
-typedef QSize UMLSceneSize;
-typedef QLine UMLSceneLine;
-typedef int UMLSceneValue;
+typedef QPointF UMLScenePoint;
+typedef QRectF UMLSceneRect;
+typedef QSizeF UMLSceneSize;
+typedef QLineF UMLSceneLine;
+typedef qreal UMLSceneValue;
 
 // event types
 typedef QKeyEvent UMLSceneKeyEvent;
-typedef QHoverEvent UMLSceneHoverEvent;
-typedef QContextMenuEvent UMLSceneContextMenuEvent;
-//typedef QDragDropEvent UMLSceneDragDropEvent;
+typedef QGraphicsSceneHoverEvent UMLSceneHoverEvent;
+typedef QGraphicsSceneContextMenuEvent UMLSceneContextMenuEvent;
+typedef QGraphicsSceneDragDropEvent UMLSceneDragDropEvent;
+typedef QGraphicsSceneDragDropEvent UMLSceneDragEnterEvent;
+typedef QGraphicsSceneDragDropEvent UMLSceneDragMoveEvent;
 
-typedef Q3CanvasItem UMLSceneItem;
-typedef Q3CanvasItemList UMLSceneItemList;
+// migration wrapper for QGraphicsScene items
+typedef QList<QGraphicsItem*> UMLSceneItemList;
 
 /**
  * UMLScene instances represent diagrams.
- * The UMLScene class inherits from Q3Canvas and
- * in the future from QGraphicsScene.
+ * The UMLScene class inherits from QGraphicsScene and it owns the
+ * objects displayed (see m_WidgetList.)
  */
-class UMLScene : public Q3Canvas
+class UMLScene : public QGraphicsScene
 {
     Q_OBJECT
 public:
-    friend QDebug operator<<(QDebug out, const UMLScene *item);
     friend class UMLViewImageExporterModel;
 
     UMLScene(UMLFolder *parentFolder, UMLView *view=0);
     virtual ~UMLScene();
 
-    Q3Canvas *canvas()
-    {
-        return this;
-    }
-
-    UMLView *view();
-    void setView(UMLView *view);
+    UMLView* activeView() const;
 
     // Accessors and other methods dealing with loaded/saved data
 
@@ -130,7 +130,7 @@ public:
     const QColor& gridDotColor() const;
     void setGridDotColor(const QColor& color);
 
-    void setSize(int width, int height);
+    void setSize(UMLSceneValue width, UMLSceneValue height);
 
     bool snapToGrid() const;
     void setSnapToGrid(bool bSnap);
@@ -142,8 +142,8 @@ public:
     int snapY() const;
     void setSnapSpacing(int x, int y);
 
-    int snappedX(int x);
-    int snappedY(int y);
+    UMLSceneValue snappedX(UMLSceneValue x);
+    UMLSceneValue snappedY(UMLSceneValue y);
 
     bool isSnapGridVisible() const;
     void setSnapGridVisible(bool bShow);
@@ -188,7 +188,7 @@ public:
 
     void removeWidget(UMLWidget *o);
 
-    void setSelected(UMLWidget *w, QMouseEvent *me);
+    void setSelected(UMLWidget *w, QGraphicsSceneMouseEvent *me);
     UMLWidgetList selectedWidgets() const;
     void clearSelected();
 
@@ -213,7 +213,9 @@ public:
 
     bool isSavedInSeparateFile();
 
-    void setMenu();
+    void setMenu(const QPoint& pos);
+
+    void resetToolbar();
 
     bool getPaste() const;
     void setPaste(bool paste);
@@ -245,8 +247,8 @@ public:
 
     void updateDocumentation(bool clear);
 
-    void getDiagram(const UMLSceneRect &rect, QPixmap & diagram);
-    void getDiagram(const UMLSceneRect &area, QPainter & painter);
+    void getDiagram(QPixmap & diagram, const UMLSceneRect &rect);
+    void getDiagram(QPainter &painter, const UMLSceneRect &source, const UMLSceneRect &target = UMLSceneRect());
 
     void copyAsImage(QPixmap*& pix);
 
@@ -269,8 +271,6 @@ public:
 
     void updateContainment(UMLCanvasObject *self);
 
-    bool showPropDialog();
-
     void setClassWidgetOptions(ClassOptionsPage * page);
 
     void checkSelections();
@@ -325,7 +325,7 @@ public:
 
     int generateCollaborationId();
 
-    void mousePressEvent(UMLSceneMouseEvent* event);
+    UMLSceneItemList collisions(const UMLScenePoint &p);
 
 protected:
     // Methods and members related to loading/saving
@@ -355,21 +355,18 @@ protected:
     bool m_bUseSnapComponentSizeToGrid;  ///< Flag to use snap to grid for component size. The default is off.
     bool m_isOpen;  ///< Flag is set to true when diagram is open, i.e. shown to the user.
 
-    int m_nSnapX;  ///< The snap to grid x size.
-    int m_nSnapY;  ///< The snap to grid y size.
-    bool m_bShowSnapGrid;  ///< Determines whether to show the snap grid. The default will be on if the grid is on.
-    int m_nCanvasWidth;    ///< Width of canvas in pixels.
-    int m_nCanvasHeight;   ///< Height of canvas in pixels.
-
     // End of methods and members related to loading/saving
     ////////////////////////////////////////////////////////////////////////
 
-    void closeEvent(QCloseEvent * e);
-    void dragEnterEvent(QDragEnterEvent* enterEvent);
-    void dragMoveEvent(QDragMoveEvent* moveEvent);
-    void dropEvent(QDropEvent* dropEvent);
+    void dragEnterEvent(UMLSceneDragDropEvent* enterEvent);
+    void dragMoveEvent(UMLSceneDragDropEvent* moveEvent);
+    void dropEvent(UMLSceneDragDropEvent* dropEvent);
 
-//    void mousePressEvent(UMLSceneMouseEvent* event);  // made public for now
+    void mouseMoveEvent(QGraphicsSceneMouseEvent* mouseEvent);
+    void mousePressEvent(QGraphicsSceneMouseEvent* mouseEvent);
+    void mouseDoubleClickEvent(QGraphicsSceneMouseEvent* mouseEvent);
+    void mouseReleaseEvent(QGraphicsSceneMouseEvent* mouseEvent);
+    virtual void contextMenuEvent(UMLSceneContextMenuEvent* contextMenuEvent);
 
     UMLSceneRect diagramRect();
 
@@ -378,10 +375,10 @@ protected:
     void updateComponentSizes();
 
     void findMaxBoundingRectangle(const FloatingTextWidget* ft,
-                                  int& px, int& py, int& qx, int& qy);
+                                  UMLSceneValue& px, UMLSceneValue& py, UMLSceneValue& qx, UMLSceneValue& qy);
     void forceUpdateWidgetFontMetrics(QPainter *painter);
 
-    virtual void drawBackground(QPainter & painter, const QRect & clip);
+    virtual void drawBackground(QPainter *painter, const QRectF &rect);
 
     int m_nCollaborationId;  ///< Used for creating unique name of collaboration messages.
     UMLScenePoint m_Pos;
@@ -390,7 +387,7 @@ protected:
     bool m_bPaste;
     ListPopupMenu * m_pMenu;
     bool m_bStartedCut;  ///< Flag if view/children started cut operation.
-    UMLWidgetList m_selectedList;
+    UMLWidgetList m_selectedList; ///< list of selected items TODO: migrate to QGraphicsScenes selection list
 
 private:
     static const UMLSceneValue defaultCanvasSize;  ///< The default size of a diagram in pixels.
@@ -398,12 +395,15 @@ private:
     UMLView *m_view;   ///< The view to which this scene is related.
     UMLFolder *m_pFolder;  ///< The folder in which this UMLView is contained.
 
+    ToolBarStateFactory* m_pToolBarStateFactory;
+    ToolBarState* m_pToolBarState;
     IDChangeLog * m_pIDChangesLog;  ///< LocalID Changes Log for paste actions
     bool m_isActivated;             ///< True if the view was activated after the serialization(load).
     bool m_bPopupShowing;           ///< Status of a popupmenu on view. True - a popup is on view.
     UMLScenePoint m_PastePoint;     ///< The offset at which to paste the clipboard.
     UMLDoc* m_doc;                  ///< Pointer to the UMLDoc.
     UMLViewImageExporter* m_pImageExporter;  ///< Used to export the view.
+    LayoutGrid*  m_layoutGrid;      ///< layout grid in the background
 
     void createAutoAttributeAssociation(UMLClassifier *type,
                                         UMLAttribute *attr,
@@ -412,9 +412,10 @@ private:
                                          UMLForeignKeyConstraint* fkConstraint,
                                          UMLWidget* widget);
 
-public slots:
-    void show();
+    bool isWidgetOrAssociation(const UMLScenePoint& atPos);
 
+public slots:
+    void slotToolBarChanged(int c);
     void slotObjectCreated(UMLObject * o);
     void slotObjectRemoved(UMLObject * o);
     void slotMenuSelection(QAction* action);
@@ -433,6 +434,8 @@ public slots:
     void alignHorizontalDistribute();
 
 signals:
+    void sigResetToolBar();
+
     void sigFillColorChanged(Uml::IDType);
     void sigGridColorChanged(Uml::IDType);
     void sigLineColorChanged(Uml::IDType);
@@ -447,68 +450,6 @@ signals:
     void sigWidgetRemoved(UMLWidget*);
 };
 
-QDebug operator<<(QDebug debug, UMLScene *item);
+QDebug operator<<(QDebug dbg, UMLScene *item);
 
-/**
-  qt3 migration wrapper for QMouseEvent
-*/
-class  UMLSceneMouseEvent : public QMouseEvent
-{
-public:
-    UMLSceneMouseEvent(Type type, const QPoint & position, Qt::MouseButton button, Qt::MouseButtons buttons, Qt::KeyboardModifiers modifiers)
-        : QMouseEvent(type, position, button, buttons, modifiers)
-    {
-    }
-
-    UMLScenePoint scenePos() {
-        return pos();
-    }
-};
-
-class UMLSceneLineItem : public Q3CanvasLine
-{
-public:
-    UMLSceneLineItem()
-        : Q3CanvasLine(0)
-    {
-    }
-};
-
-class UMLSceneRectItem : public Q3CanvasRectangle
-{
-public:
-    UMLSceneRectItem()
-        : Q3CanvasRectangle(0)
-    {
-    }
-
-    UMLSceneRectItem(int x, int y, int w, int h)
-        : Q3CanvasRectangle(x, y, w, h, 0)
-    {
-    }
-};
-
-class UMLScenePolygonItem : public Q3CanvasPolygon
-{
-public:
-    UMLScenePolygonItem()
-        : Q3CanvasPolygon(0)
-    {
-    }
-};
-
-class UMLSceneEllipseItem : public Q3CanvasEllipse
-{
-public:
-    UMLSceneEllipseItem()
-        : Q3CanvasEllipse(0)
-    {
-    }
-
-    UMLSceneEllipseItem(int width, int height)
-        : Q3CanvasEllipse(width, height, 0)
-    {
-    }
-};
-
-#endif
+#endif // UMLSCENE_H
