@@ -14,9 +14,9 @@
 #include "basictypes.h"
 #include "umlscene.h"
 
-#include <QtCore/QObject>
-#include <QtCore/QList>
-#include <QtCore/QPoint>
+#include <QList>
+#include <QObject>
+#include <QPoint>
 
 /* how many pixels a user could click around a point */
 #define POINT_DELTA 5
@@ -37,27 +37,27 @@ class AssociationLine : public QObject
     Q_OBJECT
 public:
     // typedefs
-    typedef QList<UMLSceneLineItem*> LineList;
-    typedef QList<UMLSceneRectItem*> RectList;
+    typedef QList<QGraphicsLineItem*> LineList;
+    typedef QList<QGraphicsRectItem*> RectList;
 
     AssociationLine();
     ~AssociationLine();
 
-    QPoint point(int pointIndex) const;
-    bool setPoint(int pointIndex, const QPoint &point);
-    QPoint startPoint() const;
-    QPoint endPoint() const;
+    UMLScenePoint point(int pointIndex) const;
+    bool setPoint(int pointIndex, const UMLScenePoint &point);
+    UMLScenePoint startPoint() const;
+    UMLScenePoint endPoint() const;
 
-    bool insertPoint(int pointIndex, const QPoint &point);
-    bool removePoint(int pointIndex, const QPoint &point = QPoint(), unsigned short delta = 0);
+    bool insertPoint(int pointIndex, const UMLScenePoint &point);
+    bool removePoint(int pointIndex, const UMLScenePoint &point = UMLScenePoint(), unsigned short delta = 0);
 
     int count() const;
     void cleanup();
 
-    int closestPointIndex(const QPoint &position);
-    bool isPoint(int pointIndex, const QPoint &point, unsigned short delta = 0);
+    int closestPointIndex(const UMLScenePoint &position);
+    bool isPoint(int pointIndex, const UMLScenePoint &point, unsigned short delta = 0);
 
-    bool setEndPoints(const QPoint &start, const QPoint &end);
+    bool setEndPoints(const UMLScenePoint &start, const UMLScenePoint &end);
 
     bool hasPoints() const;
     void dumpPoints();
@@ -111,14 +111,12 @@ protected:
      * We can't use QCanvasEllipse directly for this because it doesn't
      * use the pen, i.e. QCanvasEllipse only draws filled ellipses.
      */
-    class Circle : public UMLSceneEllipseItem
+    class Circle : public QGraphicsEllipseItem
     {
     public:
         explicit Circle(int radius = 0);
         void setRadius(int radius);
         int getRadius() const;
-        void setX(int x);
-        void setY(int y);
 
         void drawShape(QPainter& p);
     };
@@ -126,7 +124,7 @@ protected:
     /**
      * Draw the subset Symbol
      */
-    class SubsetSymbol : public UMLSceneEllipseItem
+    class SubsetSymbol : public QGraphicsEllipseItem
     {
     public:
         explicit SubsetSymbol();
@@ -145,7 +143,7 @@ protected:
         int inclination;
     };
 
-    Q3Canvas * canvas();
+    UMLScene *canvas();
 
     void moveSelected(int pointIndex);
 
@@ -173,17 +171,17 @@ protected:
     LineList           m_HeadList;      ///< Head lines.
     LineList           m_ParallelList;  ///< The parallel line.
     bool               m_bSelected;     ///< Selected status.
-    QPolygon           m_PointArray;    ///< Contains calculated points used to draw the line head.
+    QPolygonF          m_PointArray;    ///< Contains calculated points used to draw the line head.
 
     /**
      *   Contains calculated points used to draw the line head.
      */
-    QPoint m_ArrowPointA, m_ArrowPointB, m_MidPoint, m_EgdePoint;
+    UMLScenePoint m_ArrowPointA, m_ArrowPointB, m_MidPoint, m_EgdePoint;
 
-    UMLScenePolygonItem* m_pClearPoly;  ///< A polygon object to blank out any lines we don't want to see.
+    QGraphicsPolygonItem* m_pClearPoly;  ///< A polygon object to blank out any lines we don't want to see.
     Circle*       m_pCircle;        ///< The transparent circle required by containment associations.
     SubsetSymbol* m_pSubsetSymbol;  ///< The subset notation required by Child to Category associations.
-    QPolygon      m_ParallelLines;  ///< Contains the calculated points for the parallel line on a collaboration message to use.
+    QPolygonF     m_ParallelLines;  ///< Contains the calculated points for the parallel line on a collaboration message to use.
     Region        m_DockRegion;     ///< Region where the line docks.
     bool m_bHeadCreated;
     bool m_bSubsetSymbolCreated;
