@@ -84,12 +84,12 @@ public:
 
     static bool isTextValid(const QString &text);
 
-    void paint(QPainter & p, int offsetX, int offsetY);
+    void draw(QPainter & p, int offsetX, int offsetY);
 
-    virtual bool loadFromXMI(QDomElement & qElement);
-    virtual void saveToXMI(QDomDocument & qDoc, QDomElement & qElement);
+    virtual void saveToXMI(QDomDocument& qDoc, QDomElement& qElement);
+    virtual bool loadFromXMI(QDomElement& qElement);
 
-public slots:
+public Q_SLOTS:
     virtual void slotMenuSelection(QAction* action);
     void setMessageText();
 
