@@ -11,14 +11,6 @@
 // own header
 #include "notewidget.h"
 
-//qt includes
-#include <QtGui/QPainter>
-
-// kde includes
-#include <klocale.h>
-#include <kcolordialog.h>
-#include <kinputdialog.h>
-
 // app includes
 #include "debug_utils.h"
 #include "dialog_utils.h"
@@ -29,6 +21,14 @@
 #include "umlview.h"
 #include "uml.h"
 
+// kde includes
+#include <klocale.h>
+#include <kcolordialog.h>
+#include <kinputdialog.h>
+
+// qt includes
+#include <QPainter>
+
 /**
  * Constructs a NoteWidget.
  *
@@ -55,7 +55,7 @@ NoteWidget::~NoteWidget()
 /**
  * Override default method.
  */
-void NoteWidget::paint(QPainter & p, int offsetX, int offsetY)
+void NoteWidget::draw(QPainter & p, int offsetX, int offsetY)
 {
     const int margin = 10;
     int w = width()-1;
@@ -238,7 +238,7 @@ void NoteWidget::slotMenuSelection(QAction* action)
     switch(sel) {
     case ListPopupMenu::mt_Rename:
         m_scene->updateDocumentation( false );
-        dlg = new NoteDialog( m_scene->view(), this );
+        dlg = new NoteDialog( m_scene->activeView(), this );
         if( dlg->exec() ) {
             m_scene->showDocumentation( this, true );
             doc->setModified(true);
