@@ -34,15 +34,16 @@
 #include <kmessagebox.h>
 
 // qt includes
-#include <QtCore/QPointer>
-#include <QtGui/QPainter>
-#include <QtGui/QColor>
-#include <QtGui/QMouseEvent>
+#include <QColor>
+#include <QPainter>
+#include <QPointer>
 
 using namespace Uml;
 
+DEBUG_REGISTER_DISABLED(UMLWidget)
+
 const UMLSceneSize UMLWidget::DefaultMinimumSize(50, 20);
-const UMLSceneSize UMLWidget::DefaultMaximumSize(1000, 1000);
+const UMLSceneSize UMLWidget::DefaultMaximumSize(1000, 5000);
 
 /**
  * Creates a UMLWidget object.
@@ -52,20 +53,19 @@ const UMLSceneSize UMLWidget::DefaultMaximumSize(1000, 1000);
  * @param widgetController The UMLWidgetController of this UMLWidget
  */
 UMLWidget::UMLWidget(UMLScene * scene, WidgetType type, UMLObject * o, UMLWidgetController *widgetController)
-  : WidgetBase(scene, type),
-    UMLSceneRectItem()
+  : WidgetBase(scene, type)
 {
-    setCanvas(scene->canvas());
+    scene->addItem(this);
     if (widgetController) {
         m_widgetController = widgetController;
     } else {
         m_widgetController = new UMLWidgetController(this);
     }
     init();
-    m_pObject = o;
-    if (m_pObject) {
-        connect(m_pObject, SIGNAL(modified()), this, SLOT(updateWidget()));
-        m_nId = m_pObject->id();
+    m_umlObject = o;
+    if (m_umlObject) {
+        connect(m_umlObject, SIGNAL(modified()), this, SLOT(updateWidget()));
+        m_nId = m_umlObject->id();
     }
 }
 
@@ -78,10 +78,9 @@ UMLWidget::UMLWidget(UMLScene * scene, WidgetType type, UMLObject * o, UMLWidget
  * @param widgetController The UMLWidgetController of this UMLWidget
  */
 UMLWidget::UMLWidget(UMLScene *scene, WidgetType type, Uml::IDType id, UMLWidgetController *widgetController)
-  : WidgetBase(scene, type),
-    UMLSceneRectItem()
+  : WidgetBase(scene, type)
 {
-    setCanvas(scene->canvas());
+    scene->addItem(this);
     if (widgetController) {
         m_widgetController = widgetController;
     } else {
@@ -118,7 +117,7 @@ UMLWidget& UMLWidget::operator=(const UMLWidget & other)
     m_useFillColor = other.m_useFillColor;
     m_usesDiagramFillColor = other.m_usesDiagramFillColor;
     m_usesDiagramUseFillColor = other.m_usesDiagramUseFillColor;
-    m_FillColor = other.m_FillColor;
+    m_fillColor = other.m_fillColor;
     m_Assocs = other.m_Assocs;
     m_Text = other.m_Text; //new
     m_Font = other.m_Font;
@@ -128,7 +127,7 @@ UMLWidget& UMLWidget::operator=(const UMLWidget & other)
     m_showStereotype = other.m_showStereotype;
     setX(other.x());
     setY(other.y());
-    UMLSceneRectItem::setSize(other.width(), other.height());
+    QGraphicsRectItem::setRect(rect().x(), rect().y(), other.width(), other.height());
 
     // assign volatile (non-saved) members
     m_selected = other.m_selected;
@@ -201,13 +200,55 @@ bool UMLWidget::operator==(const UMLWidget& other) const
      */
 }
 
+/**
+ * Compute the minimum possible width and height.
+ *
+ * @return UMLSceneSize(mininum_width, minimum_height)
+ */
+UMLSceneSize UMLWidget::minimumSize()
+{
+    return m_minimumSize;
+}
+
+/**
+ * This method is used to set the minimum size variable for this
+ * widget.
+ *
+ * @param newSize The size being set as minimum.
+ */
+void UMLWidget::setMinimumSize(const UMLSceneSize& newSize)
+{
+    m_minimumSize = newSize;
+}
+
+/**
+ * Compute the maximum possible width and height.
+ *
+ * @return maximum size
+ */
+UMLSceneSize UMLWidget::maximumSize()
+{
+    return m_maximumSize;
+}
+
+/**
+ * This method is used to set the maximum size variable for this
+ * widget.
+ *
+ * @param newSize The size being set as maximum.
+ */
+void UMLWidget::setMaximumSize(const UMLSceneSize& newSize)
+{
+    m_maximumSize = newSize;
+}
+
 /**
  * Calls the method with the same name in UMLWidgetController.
  * @see UMLWidgetController#mouseMoveEvent
  *
- * @param me The QMouseEvent event.
+ * @param me The QGraphicsSceneMouseEvent event.
  */
-void UMLWidget::mouseMoveEvent(QMouseEvent* me)
+void UMLWidget::mouseMoveEvent(QGraphicsSceneMouseEvent* me)
 {
     m_widgetController->mouseMoveEvent(me);
 }
@@ -216,9 +257,9 @@ void UMLWidget::mouseMoveEvent(QMouseEvent* me)
  * Calls the method with the same name in UMLWidgetController.
  * @see UMLWidgetController#mousePressEvent
  *
- * @param me The QMouseEvent event.
+ * @param me The QGraphicsSceneMouseEvent event.
  */
-void UMLWidget::mousePressEvent(QMouseEvent *me)
+void UMLWidget::mousePressEvent(QGraphicsSceneMouseEvent *me)
 {
     m_widgetController->mousePressEvent(me);
 }
@@ -228,7 +269,7 @@ void UMLWidget::mousePressEvent(QMouseEvent *me)
  */
 void UMLWidget::updateWidget()
 {
-    updateComponentSize();
+    updateGeometry();
     switch (m_baseType) {
     case WidgetBase::wt_Class:
         m_scene->createAutoAttributeAssociations(this);
@@ -252,7 +293,7 @@ void UMLWidget::updateWidget()
  * @param width  input value, may be modified by the constraint
  * @param height input value, may be modified by the constraint
  */
-void UMLWidget::constrain(int& width, int& height)
+void UMLWidget::constrain(UMLSceneValue& width, UMLSceneValue& height)
 {
     UMLSceneSize minSize = minimumSize();
     if (width < minSize.width())
@@ -266,8 +307,8 @@ void UMLWidget::constrain(int& width, int& height)
         height = maxSize.height();
 
     if (fixedAspectRatio()) {
-        UMLSceneSize size = UMLSceneRectItem::size();
-        float aspectRatio = (float)size.height()/size.width();
+        UMLSceneSize size = QGraphicsRectItem::rect().size();
+        float aspectRatio = size.width() > 0 ? (float)size.height()/size.width() : 1;
         height = width * aspectRatio;
     }
 }
@@ -276,9 +317,9 @@ void UMLWidget::constrain(int& width, int& height)
  * Calls the method with the same name in UMLWidgetController.
  * @see UMLWidgetController#mouseReleaseEvent
  *
- * @param me The QMouseEvent event.
+ * @param me The QGraphicsSceneMouseEvent event.
  */
-void UMLWidget::mouseReleaseEvent(QMouseEvent *me)
+void UMLWidget::mouseReleaseEvent(QGraphicsSceneMouseEvent *me)
 {
     m_widgetController->mouseReleaseEvent(me);
 }
@@ -303,7 +344,7 @@ void UMLWidget::init()
         m_usesDiagramFillColor = true;
         m_usesDiagramUseFillColor = true;
         const Settings::OptionState& optionState = m_scene->optionState();
-        m_FillColor = optionState.uiState.fillColor;
+        m_fillColor = optionState.uiState.fillColor;
         // FIXME: using setFont() here let umbrello hang probably because of doc->loading() not set. 
         m_Font = optionState.uiState.font;
         m_showStereotype = optionState.classState.showStereoType;
@@ -334,7 +375,7 @@ void UMLWidget::init()
     connect(m_scene, SIGNAL(sigTextColorChanged(Uml::IDType)), this, SLOT(slotTextColorChanged(Uml::IDType)));
     connect(m_scene, SIGNAL(sigLineWidthChanged(Uml::IDType)), this, SLOT(slotLineWidthChanged(Uml::IDType)));
 
-    m_pObject = NULL;
+    m_umlObject = 0;
     setZ(m_origZ = 2);  // default for most widgets
 }
 
@@ -352,7 +393,7 @@ void UMLWidget::slotMenuSelection(QAction* action)
     ListPopupMenu::MenuType sel = m_pMenu->getMenuType(action);
     switch (sel) {
     case ListPopupMenu::mt_Rename:
-        m_doc->renameUMLObject(m_pObject);
+        m_doc->renameUMLObject(m_umlObject);
         // adjustAssocs( x(), y() );  // adjust assoc lines
         break;
 
@@ -373,7 +414,7 @@ void UMLWidget::slotMenuSelection(QAction* action)
             UMLApp::app()->endMacro();
         } else if (wt == wt_Object) {
             UMLApp::app()->beginMacro(i18n("Change Properties"));
-            m_pObject->showPropertiesPagedDialog();
+            m_umlObject->showPropertiesPagedDialog();
             UMLApp::app()->endMacro();
         } else {
             uWarning() << "making properties dialog for unknown widget type";
@@ -423,7 +464,7 @@ void UMLWidget::slotMenuSelection(QAction* action)
         break;
 
     case ListPopupMenu::mt_ViewCode: {
-        UMLClassifier *c = dynamic_cast<UMLClassifier*>(m_pObject);
+        UMLClassifier *c = dynamic_cast<UMLClassifier*>(m_umlObject);
         if (c) {
             UMLApp::app()->viewCodeDocument(c);
         }
@@ -437,7 +478,7 @@ void UMLWidget::slotMenuSelection(QAction* action)
     case ListPopupMenu::mt_Change_Font:
     case ListPopupMenu::mt_Change_Font_Selection: {
         QFont font = UMLWidget::font();
-        if (KFontDialog::getFont(font, KFontChooser::NoDisplayFlags, m_scene->view())) {
+        if (KFontDialog::getFont(font, KFontChooser::NoDisplayFlags, m_scene->activeView())) {
             UMLApp::app()->executeCommand(new CmdChangeFontSelection(m_doc, m_scene, font));
         }
     }
@@ -458,15 +499,15 @@ void UMLWidget::slotMenuSelection(QAction* action)
 
     case ListPopupMenu::mt_Refactoring:
         //check if we are operating on a classifier, or some other kind of UMLObject
-        if (dynamic_cast<UMLClassifier*>(m_pObject)) {
-            UMLApp::app()->refactor(static_cast<UMLClassifier*>(m_pObject));
+        if (dynamic_cast<UMLClassifier*>(m_umlObject)) {
+            UMLApp::app()->refactor(static_cast<UMLClassifier*>(m_umlObject));
         }
         break;
 
     case ListPopupMenu::mt_Clone:
         // In principle we clone all the uml objects.
     {
-        UMLObject *pClone = m_pObject->clone();
+        UMLObject *pClone = m_umlObject->clone();
         m_scene->addObject(pClone);
     }
     break;
@@ -480,9 +521,13 @@ void UMLWidget::slotMenuSelection(QAction* action)
         ft->handleRename();
         break;
     }
+    case ListPopupMenu::mt_Resize:
+        resize();
+        m_doc->setModified();
+        break;
 
     default:
-        uDebug() << "MenuType " << ListPopupMenu::toString(sel) << " not implemented";
+        DEBUG(DBG_SRC) << "MenuType " << ListPopupMenu::toString(sel) << " not implemented";
     }
 }
 
@@ -508,10 +553,10 @@ void UMLWidget::slotFillColorChanged(Uml::IDType viewID)
         return;
     }
     if (m_usesDiagramFillColor) {
-        m_FillColor = m_scene->fillColor();
+        WidgetBase::setFillColor(m_scene->fillColor());
     }
     if (m_usesDiagramUseFillColor) {
-        m_useFillColor = m_scene->useFillColor();
+        WidgetBase::setUseFillColor(m_scene->useFillColor());
     }
     update();
 }
@@ -526,7 +571,7 @@ void UMLWidget::slotTextColorChanged(Uml::IDType viewID)
     //only change if on the diagram concerned
     if (m_scene->ID() != viewID)
         return;
-    setTextColor( m_scene->textColor() );
+    WidgetBase::setTextColor(m_scene->textColor());
     update();
 }
 
@@ -543,8 +588,7 @@ void UMLWidget::slotLineColorChanged(Uml::IDType viewID)
         return;
 
     if (m_usesDiagramLineColor) {
-        m_LineColor = m_scene->lineColor();
-        setLineColor( m_LineColor );
+        WidgetBase::setLineColor(m_scene->lineColor());
     }
     update();
 }
@@ -561,7 +605,7 @@ void UMLWidget::slotLineWidthChanged(Uml::IDType viewID)
         return;
     }
     if (m_usesDiagramLineWidth) {
-        m_LineWidth = m_scene->lineWidth();
+        WidgetBase::setLineWidth(m_scene->lineWidth());
     }
     update();
 }
@@ -570,9 +614,9 @@ void UMLWidget::slotLineWidthChanged(Uml::IDType viewID)
  * Calls the method with the same name in UMLWidgetController.
  * @see UMLWidgetController#mouseDoubleClickEvent
  *
- * @param me The QMouseEvent event.
+ * @param me The QGraphicsSceneMouseEvent event.
  */
-void UMLWidget::mouseDoubleClickEvent(QMouseEvent * me)
+void UMLWidget::mouseDoubleClickEvent(QGraphicsSceneMouseEvent * me)
 {
     m_widgetController->mouseDoubleClickEvent(me);
 }
@@ -693,9 +737,9 @@ void UMLWidget::drawSelected(QPainter * p, int offsetX, int offsetY)
  */
 bool UMLWidget::activate(IDChangeLog* /*ChangeLog  = 0 */)
 {
-    if (widgetHasUMLObject(m_baseType) && m_pObject == NULL) {
-        m_pObject = m_doc->findObjectById(m_nId);
-        if (m_pObject == NULL) {
+    if (widgetHasUMLObject(m_baseType) && m_umlObject == NULL) {
+        m_umlObject = m_doc->findObjectById(m_nId);
+        if (m_umlObject == NULL) {
             uError() << "cannot find UMLObject with id=" << ID2STR(m_nId);
             return false;
         }
@@ -703,10 +747,10 @@ bool UMLWidget::activate(IDChangeLog* /*ChangeLog  = 0 */)
     setFont(m_Font);
     setSize(width(), height());
     m_activated = true;
-    updateComponentSize();
+    updateGeometry();
     if (m_scene->getPaste()) {
         FloatingTextWidget * ft = 0;
-        QPoint point = m_scene->getPastePoint();
+        UMLScenePoint point = m_scene->getPastePoint();
         int x = point.x() + this->x();
         int y = point.y() + this->y();
         x = x < 0 ? 0 : x;
@@ -751,7 +795,7 @@ bool UMLWidget::activate(IDChangeLog* /*ChangeLog  = 0 */)
     }
     if (m_scene->getPaste())
         m_scene->createAutoAssociations(this);
-    updateComponentSize();
+    updateGeometry();
     return true;
 }
 
@@ -904,7 +948,7 @@ ListPopupMenu* UMLWidget::setupPopupMenu(ListPopupMenu* menu)
         unique = m_scene->checkUniqueSelection();
 
     // create the right click context menu
-    m_pMenu = new ListPopupMenu(m_scene->view(), this, multi, unique);
+    m_pMenu = new ListPopupMenu(m_scene->activeView(), this, multi, unique);
 
     // disable the "view code" menu for simple code generators
     if (UMLApp::app()->isSimpleCodeGeneratorActive())
@@ -941,20 +985,27 @@ void UMLWidget::slotRemovePopupMenu()
  * @return 0 if the given point is not in the boundaries of the widget;
  *         (width()+height())/2 if the point is within the boundaries.
  */
-int UMLWidget::onWidget(const QPoint & p)
+UMLSceneValue UMLWidget::onWidget(const UMLScenePoint & p)
 {
-    const int w = width();
-    const int h = height();
-    const int left = x();
-    const int right = left + w;
-    const int top = y();
-    const int bottom = top + h;
+    const UMLSceneValue w = width();
+    const UMLSceneValue h = height();
+    const UMLSceneValue left = x();
+    const UMLSceneValue right = left + w;
+    const UMLSceneValue top = y();
+    const UMLSceneValue bottom = top + h;
     if (p.x() < left || p.x() > right ||
             p.y() < top || p.y() > bottom)   // Qt coord.sys. origin in top left corner
         return 0;
     return (w + h) / 2;
 }
 
+void UMLWidget::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
+{
+    Q_UNUSED(option); Q_UNUSED(widget);
+    draw(*painter, 0, 0);
+}
+
+
 /**
  * Move the widget by an X and Y offset relative to
  * the current position.
@@ -965,7 +1016,7 @@ void UMLWidget::moveByLocal(int dx, int dy)
     int newY = y() + dy;
     setX(newX);
     setY(newY);
-    // uDebug() << "********** x=" << newX << " / y=" << newY;
+    // DEBUG(DBG_SRC) << "********** x=" << newX << " / y=" << newY;
     adjustAssocs(newX, newY);
 }
 
@@ -974,7 +1025,7 @@ void UMLWidget::moveByLocal(int dx, int dy)
  */
 void UMLWidget::setPenFromSettings(QPainter & p)
 {
-    p.setPen(QPen(m_LineColor, m_LineWidth));
+    p.setPen(QPen(m_lineColor, m_lineWidth));
 }
 
 /**
@@ -984,68 +1035,7 @@ void UMLWidget::setPenFromSettings(QPainter & p)
  */
 void UMLWidget::drawShape(QPainter &p)
 {
-    paint(p, x(), y());
-}
-
-/**
- * Compute the minimum possible width and height.
- *
- * @return UMLSceneSize(mininum_width, minimum_height)
- */
-UMLSceneSize UMLWidget::minimumSize()
-{
-    return m_minimumSize;
-}
-
-/**
- * This method is used to set the minimum size variable for this
- * widget.
- *
- * @param newSize The size being set as minimum.
- */
-void UMLWidget::setMinimumSize(const UMLSceneSize& newSize)
-{
-    m_minimumSize = newSize;
-}
-
-void UMLWidget::setMinimumSize(UMLSceneValue width, UMLSceneValue height)
-{
-    m_minimumSize.setWidth(width);
-    m_minimumSize.setHeight(height);
-}
-
-/**
- * Compute the maximum possible width and height.
- *
- * @return maximum size
- */
-UMLSceneSize UMLWidget::maximumSize()
-{
-    return m_maximumSize;
-}
-
-/**
- * This method is used to set the maximum size variable for this
- * widget.
- *
- * @param newSize The size being set as maximum.
- */
-void UMLWidget::setMaximumSize(const UMLSceneSize& newSize)
-{
-    m_maximumSize = newSize;
-}
-
-/**
- * This method is used to set the maximum size variable for this
- * widget.
- *
- * @param width The width being set as maximum.
- * @param height The height being set as maximum.
- */
-void UMLWidget::setMaximumSize(UMLSceneValue width, UMLSceneValue height)
-{
-    m_maximumSize.setWidth(width);
-    m_maximumSize.setHeight(height);
+    draw(p, x(), y());
 }
 
 /**
@@ -1058,6 +1048,14 @@ UMLSceneSize UMLWidget::calculateSize()
     return UMLSceneSize(width(), height());
 }
 
+void UMLWidget::resize()
+{
+    // @TODO minimumSize() do not work in all cases, we need a dedicated autoResize() method
+    UMLSceneSize size = minimumSize();
+    setSize(size.width(), size.height());
+    adjustAssocs(x(), y());    // adjust assoc lines
+}
+
 /**
  * Sets the state of whether the widget is selected.
  *
@@ -1069,7 +1067,7 @@ void UMLWidget::setSelected(bool _select)
     if (_select) {
         if (m_scene->selectedCount() == 0) {
             if (widgetHasUMLObject(wt)) {
-                m_scene->showDocumentation(m_pObject, false);
+                m_scene->showDocumentation(m_umlObject, false);
             } else {
                 m_scene->showDocumentation(this, false);
             }
@@ -1089,7 +1087,7 @@ void UMLWidget::setSelected(bool _select)
     const QPoint pos(x(), y());
     UMLWidget *bkgnd = m_scene->widgetAt(pos);
     if (bkgnd && bkgnd != this && _select) {
-        uDebug() << "setting Z to " << bkgnd->z() + 1 << ", SelectState: " << _select;
+        DEBUG(DBG_SRC) << "setting Z to " << bkgnd->z() + 1 << ", SelectState: " << _select;
         setZ(bkgnd->z() + 1);
     } else {
         setZ(m_origZ);
@@ -1135,19 +1133,19 @@ void UMLWidget::setScene(UMLScene * v)
  * Gets the x-coordinate.
  */
 UMLSceneValue UMLWidget::x() const {
-    return UMLSceneRectItem::x();
+    return QGraphicsRectItem::x();
 }
 /**
  * Gets the y-coordinate.
  */
 UMLSceneValue UMLWidget::y() const {
-    return UMLSceneRectItem::y();
+    return QGraphicsRectItem::y();
 }
 /**
  * Gets the z-coordinate.
  */
 UMLSceneValue UMLWidget::z() const {
-    return UMLSceneRectItem::z();
+    return QGraphicsRectItem::zValue();
 }
 
 /**
@@ -1162,7 +1160,7 @@ void UMLWidget::setX(UMLSceneValue x)
     if (!m_ignoreSnapToGrid) {
         x = m_scene->snappedX(x);
     }
-    UMLSceneItem::setX(x);
+    QGraphicsRectItem::setX(x);
 }
 
 /**
@@ -1177,7 +1175,7 @@ void UMLWidget::setY(UMLSceneValue y)
     if (!m_ignoreSnapToGrid) {
         y = m_scene->snappedX(y);
     }
-    UMLSceneItem::setY(y);
+    QGraphicsRectItem::setY(y);
 }
 
 /**
@@ -1188,34 +1186,34 @@ void UMLWidget::setY(UMLSceneValue y)
 void UMLWidget::setZ(UMLSceneValue z)
 {
     m_origZ = this->z();
-    UMLSceneItem::setZ(z);
+    QGraphicsRectItem::setZValue(z);
 }
 
 /**
  * Sets the name in the corresponding UMLObject.
- * Sets the local m_Text if m_pObject is NULL.
+ * Sets the local m_Text if m_umlObject is NULL.
  *
  * @param strName The name to be set.
  */
 void UMLWidget::setName(const QString &strName)
 {
-    if (m_pObject)
-        m_pObject->setName(strName);
+    if (m_umlObject)
+        m_umlObject->setName(strName);
     else
         m_Text = strName;
-    updateComponentSize();
+    updateGeometry();
 }
 
 /**
  * Gets the name from the corresponding UMLObject.
- * Returns the local m_Text if m_pObject is NULL.
+ * Returns the local m_Text if m_umlObject is NULL.
  *
  * @return The currently set name.
  */
 QString UMLWidget::name() const
 {
-    if (m_pObject)
-        return m_pObject->name();
+    if (m_umlObject)
+        return m_umlObject->name();
     return m_Text;
 }
 
@@ -1280,7 +1278,7 @@ bool UMLWidget::getIgnoreSnapToGrid() const
  * If m_scene->snapComponentSizeToGrid() is true, then
  * set the next larger size that snaps to the grid.
  */
-void UMLWidget::setSize(int width, int height)
+void UMLWidget::setSize(UMLSceneValue width, UMLSceneValue height)
 {
     // snap to the next larger size that is a multiple of the grid
     if (!m_ignoreSnapComponentSizeToGrid
@@ -1295,19 +1293,19 @@ void UMLWidget::setSize(int width, int height)
             height = (numY + 1) * m_scene->snapY();
     }
 
-    UMLSceneRectItem::setSize(width, height);
+    QGraphicsRectItem::setRect(rect().x(), rect().y(), width, height);
 }
 
 /**
  * Update the size of this widget.
  */
-void UMLWidget::updateComponentSize()
+void UMLWidget::updateGeometry()
 {
     if (m_doc->loading())
         return;
-    QSize size = calculateSize();
-    int clipWidth = size.width();
-    int clipHeight = size.height();
+    UMLSceneSize size = calculateSize();
+    UMLSceneValue clipWidth = size.width();
+    UMLSceneValue clipHeight = size.height();
     constrain(clipWidth, clipHeight);
     setSize(clipWidth, clipHeight);
     adjustAssocs(x(), y());    // adjust assoc lines
@@ -1319,8 +1317,8 @@ void UMLWidget::updateComponentSize()
  */
 void UMLWidget::clipSize()
 {
-    int clipWidth = width();
-    int clipHeight = height();
+    UMLSceneValue clipWidth = width();
+    UMLSceneValue clipHeight = height();
     constrain(clipWidth, clipHeight);
     setSize(clipWidth, clipHeight);
 }
@@ -1457,7 +1455,7 @@ void UMLWidget::forceUpdateFontMetrics(QPainter *painter)
     if (m_doc->loading())
         return;
     // calculate the size, based on the new font metric
-    updateComponentSize();
+    updateGeometry();
 }
 
 /**
@@ -1468,7 +1466,7 @@ void UMLWidget::forceUpdateFontMetrics(QPainter *painter)
 void UMLWidget::setShowStereotype(bool flag)
 {
     m_showStereotype = flag;
-    updateComponentSize();
+    updateGeometry();
     update();
 }
 
@@ -1487,7 +1485,7 @@ bool UMLWidget::showStereotype() const
  *
  * @param me The move event.
  */
-void UMLWidget::moveEvent(QMoveEvent* /*me*/)
+void UMLWidget::moveEvent(QGraphicsSceneMouseEvent* /*me*/)
 {
 }
 
