@@ -11,15 +11,15 @@
 #ifndef UMLWIDGET_H
 #define UMLWIDGET_H
 
-#include <QtCore/QDateTime>
-#include <QtGui/QFont>
-
 #include "basictypes.h"
 #include "widgetbase.h"
 #include "associationwidgetlist.h"
 #include "optionstate.h"
 #include "umlscene.h"
 
+#include <QDateTime>
+#include <QFont>
+
 class UMLWidgetController;
 
 class UMLObject;
@@ -39,7 +39,7 @@ class QFontMetrics;
  * @author  Paul Hensgen <phensgen@techie.com>
  * Bugs and comments to uml-devel@lists.sf.net or http://bugs.kde.org
  */
-class UMLWidget : public WidgetBase, public UMLSceneRectItem
+class UMLWidget : public WidgetBase, public QGraphicsRectItem
 {
     Q_OBJECT
 public:
@@ -59,6 +59,12 @@ public:
 
     bool operator==(const UMLWidget& other) const;
 
+    virtual UMLSceneSize minimumSize();
+    void setMinimumSize(const UMLSceneSize &size);
+
+    virtual UMLSceneSize maximumSize();
+    void setMaximumSize(const UMLSceneSize &size);
+
     void setUseFillColor(bool fc);
 
     virtual void setTextColor(const QColor &color);
@@ -91,7 +97,7 @@ public:
 
     virtual bool activate(IDChangeLog* ChangeLog = 0);
 
-    virtual int onWidget(const QPoint & p);
+    virtual UMLSceneValue onWidget(const UMLScenePoint & p);
 
     /**
      * Draws the UMLWidget on the given paint device
@@ -101,7 +107,8 @@ public:
      * @param offsetY y position to start the drawing.
      *
      */
-    virtual void paint(QPainter & p, int offsetX, int offsetY) = 0;
+    virtual void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget = 0);
+    virtual void draw(QPainter & p, int offsetX, int offsetY) = 0;
 
     void setPenFromSettings(QPainter & p);
 
@@ -130,17 +137,17 @@ public:
      * Returns the height of widget.
      */
     int height() const {
-        return UMLSceneRectItem::height();
+        return QGraphicsRectItem::rect().height();
     }
 
     /**
      * Returns the width of the widget.
      */
-    int width() const {
-        return UMLSceneRectItem::width();
+    UMLSceneValue width() const {
+        return QGraphicsRectItem::rect().width();
     }
 
-    void setSize(int width,int height);
+    void setSize(UMLSceneValue width,UMLSceneValue height);
 
     bool getIgnoreSnapToGrid() const;
     void setIgnoreSnapToGrid(bool to);
@@ -206,7 +213,7 @@ public:
 
     static bool widgetHasUMLObject(WidgetBase::WidgetType type);
 
-    void updateComponentSize();
+    void updateGeometry();
 
     void clipSize();
 
@@ -217,29 +224,30 @@ public:
 
     UMLWidgetController* getWidgetController();
 
-    virtual void mousePressEvent(QMouseEvent *me);
-    virtual void mouseMoveEvent(QMouseEvent* me);
-    virtual void mouseReleaseEvent(QMouseEvent * me);
-    virtual void mouseDoubleClickEvent(QMouseEvent *me);
+    virtual void mouseMoveEvent(QGraphicsSceneMouseEvent * me);
+    virtual void mousePressEvent(QGraphicsSceneMouseEvent *me);
+    virtual void mouseDoubleClickEvent(QGraphicsSceneMouseEvent *me);
+    virtual void mouseReleaseEvent(QGraphicsSceneMouseEvent * me);
 
-protected:
+    UMLScene* canvas() const
+    {
+        return umlScene();
+    }
 
-    virtual void moveEvent(QMoveEvent *me);
+    void setCanvas(UMLScene *scene)
+    {
+        scene->addItem(this);
+    }
 
-    virtual void constrain(int& width, int& height);
+    virtual void moveEvent(QGraphicsSceneMouseEvent *me);
+
+    virtual void constrain(UMLSceneValue& width, UMLSceneValue& height);
 
     virtual void drawSelected(QPainter * p, int offsetX, int offsetY);
     virtual void drawShape(QPainter &p);
 
-    virtual UMLSceneSize minimumSize();
-    void setMinimumSize(const UMLSceneSize &size);
-    void setMinimumSize(UMLSceneValue width, UMLSceneValue height);
-
-    virtual UMLSceneSize maximumSize();
-    void setMaximumSize(const UMLSceneSize &size);
-    void setMaximumSize(UMLSceneValue width, UMLSceneValue height);
-
     virtual UMLSceneSize calculateSize();
+    void resize();
 
     bool fixedAspectRatio()
     {
